# R Script for the publication:
# Emmitt, J. et al. 2021. A comparison of volumetric reconstruction methods on archaeological deposits using point-cloud data. Submitted to Remote Sensing.

# Set the working directory to this R Script's location and ensure all required files are in the same folder:
#   volume_stats.csv
#   surfacearea_stats.csv
#   mesh_rank.csv
#   densities.csv
library(tidyverse)
library(rstatix)
options(scipen = 20)

# Read in data ------------------------------------------------------------------------------------

# ~ Volumes -----
volumes <- read_csv("volume_stats.csv", col_names = TRUE)
volumes$Deposit = factor(volumes$Deposit, levels = c(42717, 43017, 43019, 43020, 43021, 43022, 43023, 30754))

# Wrangle volume data for plotting
volumes_plotting <- volumes %>% 
  dplyr::select(2:9) %>% 
  pivot_longer(cols = 2:8, names_to = "type", values_to = "volume") %>% 
  mutate(method = word(type, 1, sep = "_"), type = word(type, 2, sep = "_"))
volumes_plotting$method = factor(volumes_plotting$method, levels = c("PG", "TS", "SLAM", "Point"))


# ~ Surface areas -----
surfaces <- read_csv("surfacearea_stats.csv", col_names = TRUE)
surfaces$Deposit = factor(surfaces$Deposit, levels = c(42717, 43017, 43019, 43020, 43021, 43022, 43023, 30754))

# Wrangle surface data for plotting
surfaces_plotting <- surfaces %>% 
  dplyr::select(2:9) %>% 
  pivot_longer(cols = 2:8, names_to = "type", values_to = "volume") %>% 
  mutate(method = word(type, 1, sep = "_"), type = word(type, 2, sep = "_"))
surfaces_plotting$method = factor(surfaces_plotting$method, levels = c("PG", "TS", "SLAM", "Point"))


# ~ Mesh ranks -----
ranks <- read_csv("mesh_rank.csv") %>% 
  mutate(Deposit = as.character(Deposit))

# Wrangle rank data for plotting
ranks_plotting <- ranks %>% 
  pivot_longer(cols = 2:4, names_to = "method", values_to = "rank")
ranks_plotting$method = factor(ranks_plotting$method, levels = c("TS", "SLAM", "PG"))


# ~ Densities -----
densities <- read_csv("densities.csv", col_names = TRUE)
densities$Method = factor(densities$Method, levels = c("PG", "TS", "SLAM", "Point"))
densities$Artefact = factor(densities$Artefact, levels = c("FCR", "ROCK", "SA", "TOTAL"))




# Statistically test volume methods against associated convex hulls -------------------------------

# Photogrammetry vs CH
shapiro.test((volumes$PG_Mesh - volumes$PG_CH))                     # Normal
t.test(volumes$PG_Mesh, volumes$PG_CH, paired = TRUE)               # Significant

# TS vs CH
shapiro.test((volumes$TS_Mesh - volumes$TS_CH))                     # Normal
t.test(volumes$TS_Mesh, volumes$TS_CH, paired = TRUE)               # Significant

# SLAM vs CH
shapiro.test((volumes$SLAM_Mesh - volumes$SLAM_CH))                 # Normal
t.test(volumes$SLAM_Mesh, volumes$SLAM_CH, paired = TRUE)           # Significant




# Statistically test volume methods against each other --------------------------------------------

# Friedman's Test
volumes_mesh <- volumes %>% 
  dplyr::select(Order, PG_Mesh, TS_Mesh, SLAM_Mesh) %>% 
  pivot_longer(-Order, names_to = "method", values_to = "volume") %>% 
  convert_as_factor(Order, method)

friedman_test(volumes_mesh, volume ~ method | Order)
friedman_effsize(volumes_mesh, volume ~ method | Order)

# Photogrammetry vs TS
shapiro.test((volumes$PG_Mesh - volumes$TS_Mesh))                   # Not normal
wilcox.test(volumes$PG_Mesh, volumes$TS_Mesh, paired = TRUE)        # Not significant

# Photogrammetry vs SLAM
shapiro.test((volumes$PG_Mesh - volumes$SLAM_Mesh))                 # Not normal
wilcox.test(volumes$PG_Mesh, volumes$SLAM_Mesh, paired = TRUE)      # Not significant

# TS vs SLAM
shapiro.test((volumes$TS_Mesh - volumes$SLAM_Mesh))                 # Normal
t.test(volumes$TS_Mesh, volumes$SLAM_Mesh, paired = TRUE)           # Not significant




# Statistically test volume CHs against each other ------------------------------------------------

# Friedman's Test
volumes_CH <- volumes %>% 
  dplyr::select(Order, PG_CH, TS_CH, SLAM_CH) %>% 
  pivot_longer(-Order, names_to = "method", values_to = "volume") %>% 
  convert_as_factor(Order, method)

friedman_test(volumes_CH, volume ~ method | Order)
friedman_effsize(volumes_CH, volume ~ method | Order)

# Photogrammetry vs TS
shapiro.test((volumes$PG_CH - volumes$TS_CH))                       # Normal
t.test(volumes$PG_CH, volumes$TS_CH, paired = TRUE)                 # Significant

# Photogrammetry vs SLAM
shapiro.test((volumes$PG_CH - volumes$SLAM_CH))                     # Normal
t.test(volumes$PG_CH, volumes$SLAM_CH, paired = TRUE)               # Not significant

# TS vs SLAM
shapiro.test((volumes$TS_CH - volumes$SLAM_CH))                     # Normal                 
t.test(volumes$TS_CH, volumes$SLAM_CH, paired = TRUE)               # Significant




# Plot volumes ------------------------------------------------------------------------------------
ggplot(data = volumes_plotting) +
  geom_col(data = volumes_plotting[volumes_plotting$type == "CH", ], aes(x = method, y = volume, fill = "CH"), position = "dodge") +
  geom_col(data = volumes_plotting[volumes_plotting$type == "Mesh", ], aes(x = method, y = volume, fill = "Mesh"), width = 0.5, position = position_dodge(width = 0.9)) +
  facet_wrap(vars(Order), nrow = 2, ncol = 4) +
  labs(x = "Method", y = "Volume (cubic metres)") +
  theme_bw() +
  scale_fill_manual(name = "", values = c("CH" = "grey45", "Mesh" = "black")) +
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1))



# Statistically test surfaces against associated convex hulls -------------------------------------

# Photogrammetry vs CH
shapiro.test((surfaces$PG_Mesh - surfaces$PG_CH))                   # Normal
t.test(surfaces$PG_Mesh, surfaces$PG_CH, paired = TRUE)             # Significant

# TS vs CH
shapiro.test((surfaces$TS_Mesh - surfaces$TS_CH))                   # Not normal
wilcox.test(surfaces$TS_Mesh, surfaces$TS_CH, paired = TRUE)        # Significant

# SLAM vs CH
shapiro.test((surfaces$SLAM_Mesh - surfaces$SLAM_CH))               # Normal
t.test(surfaces$SLAM_Mesh, surfaces$SLAM_CH, paired = TRUE)         # Significant




# Statistically test surfaces against each other --------------------------------------------------

# Friedman's Test
surfaces_mesh <- surfaces %>% 
  dplyr::select(Order, PG_Mesh, TS_Mesh, SLAM_Mesh) %>% 
  pivot_longer(-Order, names_to = "method", values_to = "surface") %>% 
  convert_as_factor(Order, method)

friedman_test(surfaces_mesh, surface ~ method | Order)
friedman_effsize(surfaces_mesh, surface ~ method | Order)

# Photogrammetry vs TS
shapiro.test((surfaces$PG_Mesh - surfaces$TS_Mesh))                 # Normal
t.test(surfaces$PG_Mesh, surfaces$TS_Mesh, paired = TRUE)           # Not significant

# Photogrammetry vs SLAM
shapiro.test((surfaces$PG_Mesh - surfaces$SLAM_Mesh))               # Normal 
t.test(surfaces$PG_Mesh, surfaces$SLAM_Mesh, paired = TRUE)         # Not significant

# TS vs SLAM
shapiro.test((surfaces$TS_Mesh - surfaces$SLAM_Mesh))               # Not normal
wilcox.test(surfaces$TS_Mesh, surfaces$SLAM_Mesh, paired = TRUE)    # Not significant




# Statistically test surface CHs against each other -----------------------------------------------

# Friedman's Test
surfaces_CH <- surfaces %>% 
  dplyr::select(Order, PG_CH, TS_CH, SLAM_CH) %>% 
  pivot_longer(-Order, names_to = "method", values_to = "surface") %>% 
  convert_as_factor(Order, method)

friedman_test(surfaces_CH, surface ~ method | Order)
friedman_effsize(surfaces_CH, surface ~ method | Order)

# Photogrammetry vs TS
shapiro.test((surfaces$PG_CH - surfaces$TS_CH))                     # Normal
t.test(surfaces$PG_CH, surfaces$TS_CH, paired = TRUE)               # Significant

# Photogrammetry vs SLAM
shapiro.test((surfaces$PG_CH - surfaces$SLAM_CH))                   # Normal
t.test(surfaces$PG_CH, surfaces$SLAM_CH, paired = TRUE)             # Significant

# TS vs SLAM
shapiro.test((surfaces$TS_CH - surfaces$SLAM_CH))                   # Normal
t.test(surfaces$TS_CH, surfaces$SLAM_CH, paired = TRUE)             # Significant




# Plot surfaces -----------------------------------------------------------------------------------
ggplot(data = surfaces_plotting) +
  geom_col(data = surfaces_plotting[surfaces_plotting$type == "CH", ], aes(x = method, y = volume, fill = "CH"), position = "dodge") +
  geom_col(data = surfaces_plotting[surfaces_plotting$type == "Mesh", ], aes(x = method, y = volume, fill = "Mesh"), width = 0.5, position = position_dodge(width = 0.9)) +
  facet_wrap(vars(Order), nrow = 2, ncol = 4) +
  labs(x = "Method", y = "Surface area (square metres)") +
  theme_bw() +
  scale_fill_manual(name = "", values = c("CH" = "grey45", "Mesh" = "black")) +
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1))




# Plot mesh ranks ---------------------------------------------------------------------------------
ggplot(ranks_plotting, aes(x = method, y = rank, fill = Deposit)) +
  geom_col(position = "dodge", color = "black") +
  labs(x = "Method", y = "Rank order of mesh estimate", fill = "Layer") +
  theme_bw() +
  scale_fill_brewer(type = "seq", palette = "Greys")




# Plot densities ----------------------------------------------------------------------------------
ggplot(data = densities) +
  geom_col(data = densities[densities$Type == "CH", ], aes(x = Method, y = log(Density), fill = "CH"), position = "dodge") +
  geom_col(data = densities[densities$Type == "Mesh", ], aes(x = Method, y = log(Density), fill = "Mesh"), width = 0.5, position = position_dodge(width = 0.9)) +
  facet_grid(rows = vars(Artefact), cols = vars(Order)) +
  labs(x = "Method", y = "Log Density (artefacts per cubic metre)") +
  theme_bw() +
  scale_fill_manual(name = "", values = c("CH" = "grey45", "Mesh" = "black")) +
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1))
